<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.ui" line="+14"/>
        <source>About Transmission</source>
        <translation>Info zu Transmission</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Copyright © The Transmission Project</source>
        <translation>Copyright © Das Transmission Projekt</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>A fast and easy BitTorrent client</source>
        <translation>Ein schneller und einfacher BitTorrent-Klient</translation>
    </message>
    <message>
        <location filename="../AboutDialog.cc" line="+37"/>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>C&amp;redits</source>
        <translation>&amp;Mitwirkende</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;License</source>
        <translation>&amp;Lizenz</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Credits</source>
        <translation>Mitwirkende</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message numerus="yes">
        <location filename="../Application.cc" line="+313"/>
        <source>Torrent(s) Completed</source>
        <translation>
            <numerusform>Torrent abgeschlossen</numerusform>
            <numerusform>Torrents abgeschlossen</numerusform>
        </translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Torrent Added</source>
        <translation>Torrent hinzugefügt</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../DetailsDialog.cc" line="+469"/>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mixed</source>
        <translation>Gemischt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+268"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location line="-210"/>
        <source>Finished</source>
        <translation>Beendet</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>%1 (+%2 discarded after failed checksum)</source>
        <translation>%1 (+%2 verworfen aufgrund Prüfsummenfehler)</translation>
    </message>
    <message>
        <location line="+130"/>
        <source>Active now</source>
        <translation>Jetzt aktiv</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 ago</source>
        <translation>Vor %1</translation>
    </message>
    <message numerus="yes">
        <location line="+63"/>
        <source>%1 (%Ln pieces @ %2)</source>
        <translation>
            <numerusform>%1 (%Ln Teil @ %2)</numerusform>
            <numerusform>%1 (%Ln Teile @ %2)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source>%1 (%Ln pieces)</source>
        <translation>
            <numerusform>%1 (%Ln Teil)</numerusform>
            <numerusform>%1 (%Ln Teile)</numerusform>
        </translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Private to this tracker -- DHT and PEX disabled</source>
        <translation>Geheim auf diesem Tracker -- DHT und PEX sind deaktiviert</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Public torrent</source>
        <translation>Öffentlicher Torrent</translation>
    </message>
    <message>
        <location line="+102"/>
        <source>Created by %1</source>
        <translation>Erstellt von %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created on %1</source>
        <translation>Erstellt auf %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created by %1 on %2</source>
        <translation>Erstellt von %1 am %2</translation>
    </message>
    <message>
        <location line="+207"/>
        <location line="+47"/>
        <source>Encrypted connection</source>
        <translation>Verschlüsselte Verbindung</translation>
    </message>
    <message>
        <location line="-28"/>
        <source>Optimistic unchoke</source>
        <translation>Optimistisches Entdrosseln</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading from this peer</source>
        <translation>Von diesem Peer herunterladen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would download from this peer if they would let us</source>
        <translation>Wir würden von diesem Peer herunterladen, wenn Sie uns lassen würden</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Uploading to peer</source>
        <translation>Lade zu Peer hoch</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would upload to this peer if they asked</source>
        <translation>Wir würden </translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer has unchoked us, but we&apos;re not interested</source>
        <translation>Peer hat uns entdrosselt, aber wir sind nicht interessiert.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We unchoked this peer, but they&apos;re not interested</source>
        <translation>Wir haben diesen Peer entdrosselt, aber dieser ist nicht interessiert.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer was discovered through DHT</source>
        <translation>Peer wurde durch DHT entdeckt</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer was discovered through Peer Exchange (PEX)</source>
        <translation>Peer wurde entdeckt durch Peer Exchange (PEX)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is an incoming connection</source>
        <translation>Peer ist eine eingehende Verbindung</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is connected over µTP</source>
        <translation>Peer ist über uTP verbunden</translation>
    </message>
    <message>
        <location line="+161"/>
        <source>Add tracker announce URLs, one per line:</source>
        <translation>Tracker Announce URL hinzufügen, eine pro Zeile:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No new URLs found.</source>
        <translation>Keine neuen URLs gefunden.</translation>
    </message>
    <message>
        <location line="-872"/>
        <source>%1 (100%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data</extracomment>
        <translation>%1 (100%)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data, %2 is overall size of torrent data, %3 is percentage (%1/%2*100)</extracomment>
        <translation>%1 von %2 (%3%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%), %4 Unverified</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded data (both verified and unverified), %2 is overall size of torrent data, %3 is percentage (%1/%2*100), %4 is amount of downloaded but not yet verified data</extracomment>
        <translation>%1 von %2 (%3%); %4 ungeprüft</translation>
    </message>
    <message>
        <location line="+70"/>
        <source>%1 (Ratio: %2)</source>
        <translation>%1 (Verhältnis: %2)</translation>
    </message>
    <message>
        <location line="+303"/>
        <location line="+55"/>
        <source>N/A</source>
        <translation>Nicht verfügbar</translation>
    </message>
    <message numerus="yes">
        <location line="+358"/>
        <source>%1 minute(s)</source>
        <extracomment>Spin box format, &quot;Stop seeding if idle for: [ 5 minutes ]&quot;</extracomment>
        <translation>
            <numerusform>%1 Minute(n)</numerusform>
            <numerusform>%1 Minute(n)</numerusform>
        </translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Add URL(s)</source>
        <translation>URL(s) hinzufügen</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Niedrig</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+4"/>
        <source>Use Global Settings</source>
        <translation>Globale Einstellungen verwenden</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Seed regardless of ratio</source>
        <translation>Ungeachtet des Verhältnisses verteilen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding at ratio:</source>
        <translation>Verteilen bei diesem Verhältnis stoppen:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Seed regardless of activity</source>
        <translation>Ungeachtet der Aktivität verteilen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding if idle for:</source>
        <translation>Verteilung stoppen, wenn untätig für:</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Up</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Down</source>
        <translation>Runter</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <location filename="../DetailsDialog.ui" line="+14"/>
        <source>Torrent Properties</source>
        <translation>Torrent-Eigenschaften</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Activity</source>
        <translation>Aktivität:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Have:</source>
        <translation>Vorhanden:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Availability:</source>
        <translation>Verfügbarkeit:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Uploaded:</source>
        <translation>Hochgeladen:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Downloaded:</source>
        <translation>Runtergeladen:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>State:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Running time:</source>
        <translation>Laufzeit:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Remaining time:</source>
        <translation>Verbleibende Zeit:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Last activity:</source>
        <translation>Letzte Aktivität:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Error:</source>
        <translation>Fehler:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Location:</source>
        <translation>Ort:</translation>
    </message>
    <message>
        <location line="+154"/>
        <source>Labels:</source>
        <translation>Beschriftungen:</translation>
    </message>
    <message>
        <location line="-122"/>
        <source>Hash:</source>
        <translation>Hash:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Privacy:</source>
        <translation>Datenschutz:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Origin:</source>
        <translation>Herkunft:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Added:</source>
        <translation>Hinzugefügt:</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Peers</source>
        <translation>Peers</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Show &amp;more details</source>
        <translation>Zeige &amp;mehr Details</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show &amp;backup trackers</source>
        <translation>&amp;Alternativ-Tracker anzeigen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Honor global &amp;limits</source>
        <translation>G&amp;lobale Beschränkungen beachten</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Limit &amp;download speed:</source>
        <translation>&amp;Download-Geschwindigkeit beschränken:</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>Limit &amp;upload speed:</source>
        <translation>&amp;Upload-Geschwindigkeit beschränken:</translation>
    </message>
    <message>
        <location line="-100"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Torrent &amp;priority:</source>
        <translation>Torrent-&amp;Priorität:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Seeding Limits</source>
        <translation>Verteilungsbeschränkungen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Ratio:</source>
        <translation>Ve&amp;rhältnis:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>&amp;Idle:</source>
        <translation>&amp;Inaktivität:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Peer Connections</source>
        <translation>Peer-Verbindungen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Maximum peers:</source>
        <translation>Maximale Anzahl an Peers:</translation>
    </message>
</context>
<context>
    <name>FileTreeItem</name>
    <message>
        <location filename="../FileTreeItem.cc" line="+279"/>
        <location filename="../FileTreeView.cc" line="+110"/>
        <location line="+258"/>
        <source>Low</source>
        <translation>Niedrig</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-258"/>
        <location line="+256"/>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-256"/>
        <location line="+257"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-256"/>
        <source>Mixed</source>
        <translation>Gemischt</translation>
    </message>
</context>
<context>
    <name>FileTreeModel</name>
    <message>
        <location filename="../FileTreeModel.cc" line="+203"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Priority</source>
        <translation>Priorität</translation>
    </message>
</context>
<context>
    <name>FileTreeView</name>
    <message>
        <location filename="../FileTreeView.cc" line="+248"/>
        <source>Check Selected</source>
        <translation>Ausgewählte Dateien downloaden</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uncheck Selected</source>
        <translation>Ausgewählte Dateien nicht downloaden</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Only Check Selected</source>
        <translation>Nur ausgewählte Dateien downloaden</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Priority</source>
        <translation>Priorität</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rename…</source>
        <translation>Umbenennen…</translation>
    </message>
</context>
<context>
    <name>FilterBar</name>
    <message>
        <location filename="../FilterBar.cc" line="+47"/>
        <location line="+138"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location line="-125"/>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Downloading</source>
        <translation>Lade herunter</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Seeding</source>
        <translation>Verteile</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Finished</source>
        <translation>Beendet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Verifying</source>
        <translation>Verifiziere</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location line="+142"/>
        <source>Show:</source>
        <translation>Zeige:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Search…</source>
        <translation>Suche…</translation>
    </message>
</context>
<context>
    <name>Formatter</name>
    <message>
        <location filename="../Formatter.cc" line="+19"/>
        <location line="+25"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location line="-20"/>
        <location line="+10"/>
        <location line="+19"/>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message numerus="yes">
        <location line="+30"/>
        <source>%Ln day(s)</source>
        <translation>
            <numerusform>%Ln Tag</numerusform>
            <numerusform>%Ln Tage</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-5"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%Ln Stunde</numerusform>
            <numerusform>%Ln Stunden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln Minute</numerusform>
            <numerusform>%Ln Minuten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln second(s)</source>
        <translation>
            <numerusform>%Ln Sekunde</numerusform>
            <numerusform>%Ln Sekunden</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FreeSpaceLabel</name>
    <message>
        <location filename="../FreeSpaceLabel.cc" line="+58"/>
        <source>&lt;i&gt;Calculating Free Space…&lt;/i&gt;</source>
        <translation>&lt;i&gt;Berechne freien Platz…&lt;/i&gt;</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>%1 free</source>
        <translation>%1 frei</translation>
    </message>
</context>
<context>
    <name>LicenseDialog</name>
    <message>
        <location filename="../LicenseDialog.ui" line="+14"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.ui" line="+14"/>
        <source>Transmission</source>
        <translation>Transmission</translation>
    </message>
    <message>
        <location line="+181"/>
        <source>&amp;Torrent</source>
        <translation>&amp;Torrent</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Create a new torrent</source>
        <translation>Erstelle einen neuen Torrent</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Properties</source>
        <translation>&amp;Eigenschaften</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Show torrent properties</source>
        <translation>Zeige Eigenschaften des Torrents</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open the torrent&apos;s folder</source>
        <translation>Öffne den Ordner des Torrents</translation>
    </message>
    <message>
        <location line="-161"/>
        <source>Queue</source>
        <translation>Warteschlange</translation>
    </message>
    <message>
        <location line="-132"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location line="+83"/>
        <source>Statistics</source>
        <translation>Statistiken</translation>
    </message>
    <message>
        <location line="+171"/>
        <source>&amp;Open…</source>
        <translation>&amp;Öffne…</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open</source>
        <translation>Offen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open a torrent</source>
        <translation>Öffne einen Torrent</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;New…</source>
        <translation>&amp;Neu…</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Open Fold&amp;er</source>
        <translation>Öffne Ordn&amp;er</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Start</source>
        <translation>&amp;Starte</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start torrent</source>
        <translation>Starte Torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ask Tracker for &amp;More Peers</source>
        <translation>&amp;Mehr Peers vom Tracker anfordern</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ask tracker for more peers</source>
        <translation>Mehr Peers vom Tracker anfordern</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Pause torrent</source>
        <translation>Pausiere Torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Verify Local Data</source>
        <translation>&amp;Verifiziere lokale Daten</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Verify local data</source>
        <translation>Verifiziere lokale Daten</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Remove</source>
        <translation>&amp;Entfernen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent</source>
        <translation>Entferne Torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Delete Files and Remove</source>
        <translation>Entfernen und Dateien &amp;löschen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent and delete its files</source>
        <translation>Entferne Torrent und lösche Dateien</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Start All</source>
        <translation>&amp;Starte alle</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause All</source>
        <translation>&amp;Pausiere alle</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Select All</source>
        <translation>Alle aus&amp;wählen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Deselect All</source>
        <translation>Alle a&amp;bwählen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Compact View</source>
        <translation>&amp;Kompakte Ansicht</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+3"/>
        <source>Compact View</source>
        <translation>Kompakte Ansicht</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Toolbar</source>
        <translation>&amp;Werkzeugleiste</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Filterbar</source>
        <translation>&amp;Filterleiste</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statusbar</source>
        <translation>&amp;Statusleiste</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Activity</source>
        <translation>Nach &amp;Aktivität sortieren</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by A&amp;ge</source>
        <translation>Nach A&amp;lter sortieren</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Time &amp;Left</source>
        <translation>Nach &amp;verbleibender Zeit sortieren</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Name</source>
        <translation>Nach &amp;Name sortieren</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Progress</source>
        <translation>Nach &amp;Fortschritt sortieren</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Rati&amp;o</source>
        <translation>Nach Ver&amp;hältnis sortieren</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Si&amp;ze</source>
        <translation>Nach &amp;Größe sortieren</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Stat&amp;e</source>
        <translation>Nach Status sorti&amp;eren</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by T&amp;racker</source>
        <translation>Nach T&amp;racker sortieren</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Message &amp;Log</source>
        <translation>Nachrichtenprotoko&amp;ll</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statistics</source>
        <translation>&amp;Statistiken</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Contents</source>
        <translation>&amp;Inhalte</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Re&amp;verse Sort Order</source>
        <translation>S&amp;ortierreihenfolge umkehren</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Name</source>
        <translation>&amp;Name</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Files</source>
        <translation>&amp;Dateien</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Tracker</source>
        <translation>&amp;Tracker</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Ratio</source>
        <translation>Gesamtverhältnis</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Ratio</source>
        <translation>Verhältnis der Sitzung</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Transfer</source>
        <translation>Gesamttransfer</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Transfer</source>
        <translation>Transfer der Sitzung</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Main Window</source>
        <translation>&amp;Hauptfenster</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tray &amp;Icon</source>
        <translation>Benachrichtigungssymbol</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Change Session…</source>
        <translation>&amp;Sitzung wechseln…</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Set &amp;Location…</source>
        <translation>&amp;Ort festlegen…</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Open &amp;URL…</source>
        <translation>&amp;Adresse öffnen…</translation>
    </message>
    <message>
        <location line="-15"/>
        <source>Choose Session</source>
        <extracomment>Start a local session or connect to a running session</extracomment>
        <translation>Wähle Sitzung aus</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Copy Magnet Link to Clipboard</source>
        <translation>Magnet-Link in die Zwis&amp;chenablage kopieren</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Donate</source>
        <translation>&amp;Spende</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start &amp;Now</source>
        <translation>Starte &amp;Jetzt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Bypass the queue and start now</source>
        <translation>Warteschlange überspringen und jetzt anfangen</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Move to &amp;Top</source>
        <translation>An den &amp;Anfang verschieben</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Move &amp;Up</source>
        <translation>&amp;Hoch schieben</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move &amp;Down</source>
        <translation>&amp;Runter schieben</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move to &amp;Bottom</source>
        <translation>An das &amp;Ende verschieben</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Queue</source>
        <translation>Nach War&amp;teschlange sortieren</translation>
    </message>
    <message>
        <location filename="../MainWindow.cc" line="+385"/>
        <source>Limit Download Speed</source>
        <translation>Download-Geschwindigkeit begrenzen</translation>
    </message>
    <message>
        <location line="-55"/>
        <source>Unlimited</source>
        <translation>Unbeschränkt</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+812"/>
        <location line="+9"/>
        <source>Limited at %1</source>
        <translation>Begrenzt auf %1</translation>
    </message>
    <message>
        <location line="-766"/>
        <source>Limit Upload Speed</source>
        <translation>Upload-Geschwindigkeit begrenzen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Stop Seeding at Ratio</source>
        <translation>Verteilung bei Verhältnis stoppen</translation>
    </message>
    <message>
        <location line="-40"/>
        <source>Seed Forever</source>
        <translation>Für immer verteilen</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+799"/>
        <source>Stop at Ratio (%1)</source>
        <translation>Stoppen bei Verhältnis (%1)</translation>
    </message>
    <message>
        <location line="-448"/>
        <source> - %1:%2</source>
        <extracomment>Second (optional) part of main window title &quot;Transmission - host:port&quot; (added when connected to remote session) notice that leading space (before the dash) is included here</extracomment>
        <translation> - %1:%2</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Idle</source>
        <translation>Untätig</translation>
    </message>
    <message>
        <location line="+26"/>
        <location line="+19"/>
        <source>Ratio: %1</source>
        <translation>Verhältnis: %1</translation>
    </message>
    <message>
        <location line="-14"/>
        <location line="+7"/>
        <source>Down: %1, Up: %2</source>
        <translation>Runter: %1, Hoch: %2</translation>
    </message>
    <message>
        <location line="+480"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Torrent-Dateien (*.torrent);;Alle Dateien (*.*)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show &amp;options dialog</source>
        <translation>&amp;Optionsdialog anzeigen</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Open Torrent</source>
        <translation>Torrent öffnen</translation>
    </message>
    <message>
        <location line="-1066"/>
        <source>Speed Limits</source>
        <translation>Geschwindigkeitsbegrenzungen</translation>
    </message>
    <message>
        <location line="+546"/>
        <source>Network Error</source>
        <translation>Netzwerkfehler</translation>
    </message>
    <message>
        <location line="+489"/>
        <source>Click to disable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>Klicken, um temporäre Geschwindigkeitsbegrenzungen zu deaktivieren
(%1 runter, %2 hoch)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Click to enable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>Klicken, um temporäre Geschwindigkeitsbegrenzungen zu aktivieren
(%1 runter, %2 hoch)</translation>
    </message>
    <message>
        <location line="+160"/>
        <source>Remove torrent?</source>
        <translation>Torrent entfernen?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Delete this torrent&apos;s downloaded files?</source>
        <translation>Heruntergeladene Dateien von diesem Torrent löschen?</translation>
    </message>
    <message numerus="yes">
        <location line="-4"/>
        <source>Remove %Ln torrent(s)?</source>
        <translation>
            <numerusform>%Ln Torrent entfernen?</numerusform>
            <numerusform>%Ln Torrents entfernen?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-584"/>
        <source>Showing %L1 of %Ln torrent(s)</source>
        <translation>
            <numerusform>Zeige %L1 von %Ln Torrent</numerusform>
            <numerusform>Zeige %L1 von %Ln Torrents</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+589"/>
        <source>Delete these %Ln torrent(s)&apos; downloaded files?</source>
        <translation>
            <numerusform>Die Dateien von diesem Torrent löschen?</numerusform>
            <numerusform>Die Dateien dieser %Ln Torrents löschen?</numerusform>
        </translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Once removed, continuing the transfer will require the torrent file or magnet link.</source>
        <translation>Einmal entfernt, wird das Fortführen der Übertragung eine Torrent-Datei oder einen Magnet-Link erfordern.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Once removed, continuing the transfers will require the torrent files or magnet links.</source>
        <translation>Einmal entfernt, wird das Fortführen der Übertragungen die Torrent-Dateien oder die Magnet-Links erfordern.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent has not finished downloading.</source>
        <translation>Dieser Torrent ist noch nicht abgeschlossen.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>These torrents have not finished downloading.</source>
        <translation>Diese Torrents sind noch nicht abgeschlossen.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent is connected to peers.</source>
        <translation>Dieser Torrent ist mit Peers verbunden.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>These torrents are connected to peers.</source>
        <translation>Diese Torrents sind mit Peers verbunden.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>One of these torrents is connected to peers.</source>
        <translation>Einer dieser Torrents ist mit Peers verbunden.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents are connected to peers.</source>
        <translation>Einige dieser Torrents sind mit Peers verbunden.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>One of these torrents has not finished downloading.</source>
        <translation>Einer dieser Torrents ist noch nicht abgeschlossen.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents have not finished downloading.</source>
        <translation>Einige dieser Torrents sind noch nicht abgeschlossen.</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>%1 has not responded yet</source>
        <translation>%1 hat noch nicht geantwortet</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 is responding</source>
        <translation>%1 antwortet</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 last responded %2 ago</source>
        <translation>%1 hat zuletzt vor %2 geantwortet</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 is not responding</source>
        <translation>%1 antwortet nicht</translation>
    </message>
</context>
<context>
    <name>MakeDialog</name>
    <message>
        <location filename="../MakeDialog.ui" line="+17"/>
        <source>New Torrent</source>
        <translation>Neuer Torrent</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="+305"/>
        <source>&lt;i&gt;No source selected&lt;/i&gt;</source>
        <translation>&lt;i&gt;Keine Quelle ausgewählt&lt;/i&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="+5"/>
        <source>%Ln File(s)</source>
        <translation>
            <numerusform>%Ln Datei</numerusform>
            <numerusform>%Ln Dateien</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln Piece(s)</source>
        <translation>
            <numerusform>%Ln Teil</numerusform>
            <numerusform>%Ln Teile</numerusform>
        </translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 in %2; %3 @ %4</source>
        <translation>%1 von %2; %3 @ %4</translation>
    </message>
    <message>
        <location filename="../MakeDialog.ui" line="+6"/>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Sa&amp;ve to:</source>
        <translation>Sp&amp;eichern unter:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Source f&amp;older:</source>
        <translation>Quellen-O&amp;rdner:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Source &amp;file:</source>
        <translation>Quellen-D&amp;atei:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Piece s&amp;ize:</source>
        <translation>Stück&amp;größe:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Properties</source>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Trackers:</source>
        <translation>&amp;Trackers:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>To add a backup URL, add it on the line after the primary URL.
To add another primary URL, add it after a blank line.</source>
        <translation>Um eine alternative URL hinzuzufügen, muss diese auf der Zeile nach der primären URL hinzugefügt werden.
Um eine weitere primäre URL hinzuzufügen, muss diese nach einer Leerzeile eingefügt werden.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Co&amp;mment:</source>
        <translation>Ko&amp;mmentar:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Source:</source>
        <translation>&amp;Quelle:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Private torrent</source>
        <translation>&amp;Privater Torrent</translation>
    </message>
</context>
<context>
    <name>MakeProgressDialog</name>
    <message>
        <location filename="../MakeProgressDialog.ui" line="+14"/>
        <source>New Torrent</source>
        <translation>Neuer Torrent</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="-182"/>
        <source>Creating &quot;%1&quot;</source>
        <translation>Erstelle &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Created &quot;%1&quot;!</source>
        <translation>&quot;%1&quot; erstellt!</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Couldn&apos;t create &quot;%1&quot;: %2 (%3)</source>
        <translation>&quot;%1&quot; konnte nicht erstellt werden: %2 (%3)</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../OptionsDialog.cc" line="+53"/>
        <source>Open Torrent</source>
        <translation>Öffne Torrent</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Open Torrent from File</source>
        <translation>Öffne Torrent aus Datei</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open Torrent from URL or Magnet Link</source>
        <translation>Öffne Torrent von URL oder Magnetischem Link</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+17"/>
        <source>&amp;Source:</source>
        <translation>&amp;Quelle:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Destination folder:</source>
        <translation>&amp;Zielordner:</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="+49"/>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Niedrig</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+35"/>
        <source>&amp;Priority:</source>
        <translation>&amp;Priorität:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>S&amp;tart when added</source>
        <translation>S&amp;tarte sobald hinzugefügt</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mo&amp;ve .torrent file to the trash</source>
        <translation>&amp;Verschiebe .torrent-Datei in den Papierkorb</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="-40"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Torrent-Dateien (*.torrent);;Alle Dateien (*.*)</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Select Destination</source>
        <translation>Wähle Bestimmungsort aus</translation>
    </message>
</context>
<context>
    <name>PathButton</name>
    <message>
        <location filename="../PathButton.cc" line="+23"/>
        <location line="+67"/>
        <source>(None)</source>
        <translation>(Keiner)</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Select Folder</source>
        <translation>Verzeichnis auswählen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Select File</source>
        <translation>Datei auswählen</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <location filename="../PrefsDialog.ui" line="+971"/>
        <source>Use &amp;authentication</source>
        <translation>Verwende &amp;Authentifizierung</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Username:</source>
        <translation>Ben&amp;utzername:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>Pass&amp;wort:</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>&amp;Open web client</source>
        <translation>Web-Client &amp;öffnen</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Addresses:</source>
        <translation>Adressen:</translation>
    </message>
    <message>
        <location line="-985"/>
        <source>Speed Limits</source>
        <translation>Geschwindigkeitsbegrenzungen</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>&lt;small&gt;Override normal speed limits manually or at scheduled times&lt;/small&gt;</source>
        <translation>&lt;small&gt;Überschreibe normale Geschwindigkeitsbegrenzungen manuell oder zu geplanten Zeiten&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>&amp;Scheduled times:</source>
        <translation>&amp;Geplante Zeiten:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>&amp;On days:</source>
        <translation>&amp;An Tagen:</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+381"/>
        <source>Every Day</source>
        <translation>Jeden Tag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekdays</source>
        <translation>Wochentagen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekends</source>
        <translation>Wochenenden</translation>
    </message>
    <message>
        <location line="-235"/>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message numerus="yes">
        <location line="+463"/>
        <source>%1 minute(s)</source>
        <extracomment>Spin box format, &quot;Stop seeding if idle for: [ 5 minutes ]&quot;</extracomment>
        <translation>
            <numerusform>%1 Minute(n)</numerusform>
            <numerusform>%1 Minute(n)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+26"/>
        <source>%1 minute(s) ago</source>
        <extracomment>Spin box format, &quot;Download is inactive if data sharing stopped: [ 5 minutes ago ]&quot;</extracomment>
        <translation>
            <numerusform>vor %1 Minute(n)</numerusform>
            <numerusform>vor %1 Minute(n)</numerusform>
        </translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Select &quot;Torrent Done Downloading&quot; Script</source>
        <translation>&quot;Torrent fertig heruntergeladen&quot;-Skript auswählen</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="+447"/>
        <source>Incoming Peers</source>
        <translation>Eingehende Peers</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Port for incoming connections:</source>
        <translation>&amp;Port für eingehende Verbindungen:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Use UPnP or NAT-PMP port &amp;forwarding from my router</source>
        <translation>Verwende UPnP oder NAT-PMP Port-Weiterleitung meines Routers</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="-35"/>
        <source>Select &quot;Torrent Done Seeding&quot; Script</source>
        <translation>&quot;Torrent fertig verteilt&quot;-Skript auswählen</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-520"/>
        <source>Automatically add .torrent files &amp;from:</source>
        <translation>Füge .Torrent-Dateien automatisch hinzu von:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Show the Torrent Options &amp;dialog</source>
        <translation>Zeige den Torrent-Optionen-&amp;Dialog</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Start added torrents</source>
        <translation>&amp;Starte hinzugefügte Torrents</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Mo&amp;ve the .torrent file to the trash</source>
        <translation>&amp;Verschiebe die .Torrent-Datei in den Papierkorb</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Download Queue</source>
        <translation>Download-Warteschlange</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Ma&amp;ximum active downloads:</source>
        <translation>Ma&amp;ximale Anzahl aktiver Downloads:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Incomplete</source>
        <translation>Unvollständig</translation>
    </message>
    <message>
        <location line="+74"/>
        <source>Seeding</source>
        <translation>Verteilen</translation>
    </message>
    <message>
        <location line="+361"/>
        <source>Trackers to use on all public torrents.

To add a backup URL, add it on the next line after a primary URL.
To add a new primary URL, add it after a blank line.</source>
        <translation>Zu verwendende Tracker für alle öffentlichen Torrents.

Um eine Backup-URL hinzuzufügen, fügen Sie sie in der nächsten Zeile nach einer primären URL ein.
Um eine neue primäre URL hinzuzufügen, fügen Sie sie nach einer Leerzeile ein.</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Remote</source>
        <translation>Entfernte Sitzungen</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="+180"/>
        <source>&lt;i&gt;Blocklist contains %Ln rule(s)&lt;/i&gt;</source>
        <translation>
            <numerusform>&lt;i&gt;Sperrliste enthält %Ln Regel&lt;/i&gt;</numerusform>
            <numerusform>&lt;i&gt;Sperrliste enthält %Ln Regeln&lt;/i&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-236"/>
        <source>Pick a &amp;random port every time Transmission is started</source>
        <translation>Bei jedem Sta&amp;rt von Transmission einen zufälligen Port wählen</translation>
    </message>
    <message>
        <location line="-228"/>
        <source>Limits</source>
        <translation>Begrenzungen</translation>
    </message>
    <message>
        <location line="+251"/>
        <source>Maximum peers per &amp;torrent:</source>
        <translation>Maximale Peers pro &amp;Torrent:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Maximum peers &amp;overall:</source>
        <translation>Maximale Peers &amp;gesamt:</translation>
    </message>
    <message>
        <location line="-155"/>
        <source>Blocklist</source>
        <translation>Sperrliste</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Enable &amp;automatic updates</source>
        <translation>&amp;Automatische Aktualisierungen aktivieren</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="-215"/>
        <source>Allow encryption</source>
        <translation>Erlaube Verschlüsselung</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prefer encryption</source>
        <translation>Bevorzuge Verschlüsselung</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Require encryption</source>
        <translation>Verlange Verschlüsselung</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-64"/>
        <source>Privacy</source>
        <translation>Datenschutz</translation>
    </message>
    <message>
        <location line="-372"/>
        <source>&amp;to</source>
        <translation>&amp;bis</translation>
    </message>
    <message>
        <location line="+672"/>
        <location line="+6"/>
        <source>Desktop</source>
        <translation>Arbeitsfläche</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show Transmission icon in the &amp;notification area</source>
        <translation>Zeige das Transmission-Symbol im Be&amp;nachrichtigungsfeld</translation>
    </message>
    <message>
        <location line="-192"/>
        <source>Te&amp;st Port</source>
        <translation>Port t&amp;esten</translation>
    </message>
    <message>
        <location line="-86"/>
        <source>Enable &amp;blocklist:</source>
        <translation>&amp;Sperrliste aktivieren:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Update</source>
        <translation>Akt&amp;ualisieren</translation>
    </message>
    <message>
        <location line="-42"/>
        <source>&amp;Encryption mode:</source>
        <translation>&amp;Verschlüsselungsmodus:</translation>
    </message>
    <message>
        <location line="+367"/>
        <source>Remote Control</source>
        <translation>Entfernte Steuerung</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Allow &amp;remote access</source>
        <translation>Entfe&amp;rnten Zugriff zulassen</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>HTTP &amp;port:</source>
        <translation>HTTP &amp;Port:</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Only allow these IP a&amp;ddresses:</source>
        <translation>Erlaube nur diese IP-A&amp;dressen:</translation>
    </message>
    <message>
        <location line="-969"/>
        <source>&amp;Upload:</source>
        <translation>&amp;Hochladen:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Download:</source>
        <translation>&amp;Herunterladen:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Alternative Speed Limits</source>
        <translation>Alternative Geschwindigkeitsbegrenzungen</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>U&amp;pload:</source>
        <translation>H&amp;ochladen:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Do&amp;wnload:</source>
        <translation>Heru&amp;nterladen:</translation>
    </message>
    <message>
        <location line="+142"/>
        <source>Reads user clipboard content for torrents</source>
        <translation>Zwischenablage auslesen für Torrents</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Detect new torrents from clipboard</source>
        <translation>Neue Torrents aus Zwischenablage erkennen</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Call scrip&amp;t when downloading is completed:</source>
        <translation>Skrip&amp;t ausführen, wenn Torrent-Download abgeschlossen ist:</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Call scrip&amp;t when seeding is completed:</source>
        <translation>Skrip&amp;t ausführen, wenn Torrent-Verteilung abgeschlossen ist:</translation>
    </message>
    <message>
        <location line="+254"/>
        <source>µTP is a tool for reducing network congestion.</source>
        <translation>µTP ist ein Hilfsprogramm, um die Netzwerküberlastung zu reduzieren.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Enable µ&amp;TP for peer connections</source>
        <translation>µ&amp;TP aktivieren für Peer-Kommunikation</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Default Public Trackers</source>
        <translation>Standardmäßige öffentliche Tracker</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Start &amp;minimized in notification area</source>
        <translation>&amp;Minimiert im Benachrichtigungsfeld starten</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Notification</source>
        <translation>Benachrichtigung</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show a notification when torrents are a&amp;dded</source>
        <translation>Zeige eine Benachrichtigung an, wenn Torrents h&amp;inzugefügt werden</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show a notification when torrents &amp;finish</source>
        <translation>Zeige eine Benachrichtigung, wenn Torrents &amp;beendet sind</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Play a &amp;sound when torrents finish</source>
        <translation>Ton ab&amp;spielen, wenn Torrents abgeschlossen sind</translation>
    </message>
    <message>
        <location line="-195"/>
        <source>Peer Limits</source>
        <translation>Peer-Beschränkungen</translation>
    </message>
    <message>
        <location line="+74"/>
        <source>Use PE&amp;X to find more peers</source>
        <translation>PE&amp;X verwenden, um mehr Peers zu finden</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>PEX is a tool for exchanging peer lists with the peers you&apos;re connected to.</source>
        <translation>Mit PEX können Peer-Listen mit verbundenen Peers ausgetauscht werden.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;DHT to find more peers</source>
        <translation>&amp;DHT verwenden, um mehr Peers zu finden</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>DHT is a tool for finding peers without a tracker.</source>
        <translation>Mit DHT können Peers ohne Tracker gefunden werden.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;Local Peer Discovery to find more peers</source>
        <translation>&amp;Lokale Peersuche verwenden, um mehr Peers zu finden</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>LPD is a tool for finding peers on your local network.</source>
        <translation>Mit LPD können Peers im lokalen Netwerk gefunden werden.</translation>
    </message>
    <message>
        <location line="-239"/>
        <source>Encryption</source>
        <translation>Verschlüsselung</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+67"/>
        <source>Select Incomplete Directory</source>
        <translation>Verzeichnis für unvollständige Dateien wählen</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Select Watch Directory</source>
        <translation>Zu überwachendes Verzeichnis wählen</translation>
    </message>
    <message>
        <location line="-209"/>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>checking…</source>
        <translation>Prüfe …</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>open</source>
        <translation>geöffnet</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>closed</source>
        <translation>geschlossen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Status: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Status: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Status: &lt;b&gt;%1&lt;/b&gt; (IPv4), &lt;b&gt;%2&lt;/b&gt; (IPv6)</source>
        <translation>Status: &lt;b&gt;%1&lt;/b&gt; (IPv4), &lt;b&gt;%2&lt;/b&gt; (IPv6)</translation>
    </message>
    <message numerus="yes">
        <location line="+96"/>
        <source>&lt;b&gt;Update succeeded!&lt;/b&gt;&lt;p&gt;Blocklist now has %Ln rule(s).&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;b&gt;Aktualisierung erfolgreich!&lt;/b&gt;&lt;p&gt;Sperrliste hat nun %Ln Regel.&lt;/p&gt;</numerusform>
            <numerusform>&lt;b&gt;Aktualisierung erfolgreich!&lt;/b&gt;&lt;p&gt;Sperrliste hat nun %Ln Regeln.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&lt;b&gt;Update Blocklist&lt;/b&gt;&lt;p&gt;Getting new blocklist…&lt;/p&gt;</source>
        <translation>&lt;b&gt;Aktualisiere Sperrliste&lt;/b&gt;&lt;p&gt;Neue Sperrliste wird empfangen…&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+84"/>
        <source>Select Destination</source>
        <translation>Ziel auswählen</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-323"/>
        <source>Adding</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location line="+117"/>
        <source>Download is i&amp;nactive if data sharing stopped:</source>
        <extracomment>Please keep this phrase as short as possible, it&apos;s currently the longest and influences dialog width</extracomment>
        <translation>Herunterladen ist i&amp;naktiv, wenn keine Dateien getauscht wurden seit:</translation>
    </message>
    <message>
        <location line="-123"/>
        <source>Downloading</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <location line="+158"/>
        <source>Append &quot;.&amp;part&quot; to incomplete files&apos; names</source>
        <translation>Endung &quot;&amp;part&quot; an unvollständig heruntergeladene Dateien anfügen</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Keep &amp;incomplete files in:</source>
        <translation>&amp;Unvollständige Torrents verbleiben in:</translation>
    </message>
    <message>
        <location line="-100"/>
        <source>Save to &amp;Location:</source>
        <translation>An diesem &amp;Ort speichern:</translation>
    </message>
    <message>
        <location line="+173"/>
        <source>Stop seeding at &amp;ratio:</source>
        <translation>Verteilung bei diesem Ve&amp;rhältnis stoppen:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Stop seedi&amp;ng if idle for:</source>
        <translation>Verteile&amp;n anhalten, wenn untätig für:</translation>
    </message>
    <message>
        <location line="-467"/>
        <source>Transmission Preferences</source>
        <translation>Transmission-Einstellungen</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
    <message>
        <location line="+604"/>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+114"/>
        <source>Not supported by remote sessions</source>
        <translation>Nicht unterstützt von entfernten Sitzungen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../Application.cc" line="-266"/>
        <source>B/s</source>
        <translation>B/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>kB/s</source>
        <translation>kB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>MB/s</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>GB/s</source>
        <translation>GB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>TB/s</source>
        <translation>TB/s</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+7"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>GB</source>
        <translation>GB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>TB</source>
        <translation>TB</translation>
    </message>
    <message>
        <location line="+247"/>
        <source>Start Now</source>
        <translation>Jetzt starten</translation>
    </message>
</context>
<context>
    <name>RelocateDialog</name>
    <message>
        <location filename="../RelocateDialog.cc" line="+65"/>
        <source>Select Location</source>
        <translation>Ort auswählen</translation>
    </message>
    <message>
        <location filename="../RelocateDialog.ui" line="+14"/>
        <source>Set Torrent Location</source>
        <translation>Ort für Torrent festlegen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Set Location</source>
        <translation>Ort festlegen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>New &amp;location:</source>
        <translation>Neuer &amp;Ort:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Move from the current folder</source>
        <translation>Aus &amp;momentanem Verzeichnis verschieben</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Local data is &amp;already there</source>
        <translation>&amp;Lokale Daten befinden sich bereits dort</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../Session.cc" line="+502"/>
        <source>Error Renaming Path</source>
        <translation>Fehler beim Umbenennen des Pfades</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;p&gt;&lt;b&gt;Unable to rename &quot;%1&quot; as &quot;%2&quot;: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please correct the errors and try again.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Konnte &quot;%1&quot; nicht zu &quot;%2&quot; umbenennen: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Bitte Fehler korrigieren und erneut versuchen.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+536"/>
        <source>Error Adding Torrent</source>
        <translation>Fehler beim Hinzufügen des Torrents</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>%1 (copy of %2)</source>
        <translation>%1 (Kopie von %2)</translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source>Duplicate Torrent(s)</source>
        <translation>
            <numerusform>Doppelte Torrentdatei</numerusform>
            <numerusform>Doppelte Torrentdateien</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+2"/>
        <source>Unable to add %n duplicate torrent(s)</source>
        <translation>
            <numerusform>%n doppelte Torrentdatei konnten nicht hinzugefügt werden</numerusform>
            <numerusform>%n doppelte Torrentdateien konnten nicht hinzugefügt werden</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <location filename="../SessionDialog.ui" line="+14"/>
        <source>Change Session</source>
        <translation>Sitzung wechseln</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Start &amp;Local Session</source>
        <translation>&amp;Lokale Sitzung starten</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Connect to &amp;Remote Session</source>
        <translation>Zu entfe&amp;rnter Sitzung verbinden</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Host:</source>
        <translation>&amp;Host:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Port:</source>
        <translation>&amp;Port:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Authentication required</source>
        <translation>&amp;Authentifizierung erforderlich</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Username:</source>
        <translation>Ben&amp;utzername:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>Pass&amp;wort:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Remote root pa&amp;th:</source>
        <translation>Entferntes Wurzel&amp;verzeichnis:</translation>
    </message>
</context>
<context>
    <name>Speed</name>
    <message>
        <location filename="../Speed.h" line="+40"/>
        <location line="+6"/>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <location filename="../StatsDialog.ui" line="+14"/>
        <source>Statistics</source>
        <translation>Statistiken</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Current Session</source>
        <translation>Momentane Sitzung</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+129"/>
        <source>Uploaded:</source>
        <translation>Hochgeladen:</translation>
    </message>
    <message>
        <location line="-103"/>
        <location line="+129"/>
        <source>Downloaded:</source>
        <translation>Runtergeladen:</translation>
    </message>
    <message>
        <location line="-103"/>
        <location line="+129"/>
        <source>Ratio:</source>
        <translation>Verhältnis:</translation>
    </message>
    <message>
        <location line="-103"/>
        <location line="+129"/>
        <source>Duration:</source>
        <translation>Dauer:</translation>
    </message>
    <message>
        <location line="-100"/>
        <source>Total</source>
        <translation>Gesamt</translation>
    </message>
    <message numerus="yes">
        <location filename="../StatsDialog.cc" line="+63"/>
        <source>Started %Ln time(s)</source>
        <translation>
            <numerusform>%Ln Mal gestartet</numerusform>
            <numerusform>%Ln Mal gestartet</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Torrent</name>
    <message>
        <location filename="../Torrent.cc" line="+307"/>
        <source>Verifying local data</source>
        <translation>Überprüfe lokale Daten</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Downloading</source>
        <translation>Lade herunter</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Seeding</source>
        <translation>Verteile</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Finished</source>
        <translation>Abgeschlossen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Queued for verification</source>
        <translation>Eingereiht für Überprüfung</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for download</source>
        <translation>Eingereiht für Herunterladen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for seeding</source>
        <translation>Eingereiht für Verteilen</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Tracker gave a warning: %1</source>
        <translation>Tracker gab Warnung zurück: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tracker gave an error: %1</source>
        <translation>Tracker gab Fehler zurück: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Error: %1</source>
        <translation>Fehler: %1</translation>
    </message>
</context>
<context>
    <name>TorrentDelegate</name>
    <message>
        <location filename="../TorrentDelegate.cc" line="+173"/>
        <source>Magnetized transfer - retrieving metadata (%1%)</source>
        <extracomment>First part of torrent progress string, %1 is the percentage of torrent metadata downloaded</extracomment>
        <translation>Magnetischer Transfer - Lade Metadaten herunter (%1%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is how much we&apos;ll have when done, %3 is a percentage of the two</extracomment>
        <translation>%1 von %2 (%3%)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5 Goal: %6)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio, %6 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1 von %2 (%3%), hochgeladen %4 (Verhältnis: %5 Ziel: %6)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio</extracomment>
        <translation>%1 von %2 (%3%), hochgeladen %4 (Verhältnis: %5)</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>%1, uploaded %2 (Ratio: %3 Goal: %4)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio, %4 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1, hochgeladen %2 (Verhältnis: %3 Ziel: %4)</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>%1, uploaded %2 (Ratio: %3)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio</extracomment>
        <translation>%1, hochgeladen %2 (Verhältnis: %3)</translation>
    </message>
    <message>
        <location line="+15"/>
        <source> - %1 left</source>
        <extracomment>Second (optional) part of torrent progress string, %1 is duration, notice that leading space (before the dash) is included here</extracomment>
        <translation> - %1 verbleibend</translation>
    </message>
    <message>
        <location line="+6"/>
        <source> - Remaining time unknown</source>
        <extracomment>Second (optional) part of torrent progress string, notice that leading space (before the dash) is included here</extracomment>
        <translation> - Verbleibende Zeit unbekannt</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Ratio: %1</source>
        <translation>Verhältnis: %1</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>%1 left</source>
        <extracomment>Second (optional) part of torrent progress string, %1 is duration, notice that leading space (before the dash) is included here</extracomment>
        <translation>%1 verbleibend</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Remaining time unknown</source>
        <extracomment>Second (optional) part of torrent progress string, notice that leading space (before the dash) is included here</extracomment>
        <translation>Verbleibende Zeit unbekannt</translation>
    </message>
    <message numerus="yes">
        <location line="+40"/>
        <source>Downloading from %Ln peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Lade von %Ln Peer herunter</numerusform>
            <numerusform>Lade von %Ln Peers herunter</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+22"/>
        <source>Seeding to %Ln peer(s)</source>
        <translation>
            <numerusform>Verteile an %Ln Peer</numerusform>
            <numerusform>Verteile an %Ln Peers</numerusform>
        </translation>
    </message>
    <message>
        <location line="+18"/>
        <source> - </source>
        <translation> - </translation>
    </message>
    <message numerus="yes">
        <location line="-50"/>
        <source>Downloading metadata from %Ln peer(s) (%1% done)</source>
        <translation>
            <numerusform>Lade Metadaten von %Ln Peer herunter (%1% fertig)</numerusform>
            <numerusform>Lade Metadaten von %Ln Peers herunter (%1% fertig)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+15"/>
        <source>Downloading from %1 of %Ln connected peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Lade von %1 von %Ln verbundenem Peer herunter</numerusform>
            <numerusform>Lade von %1 von %Ln verbundenen Peers herunter</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+8"/>
        <source> and %Ln web seed(s)</source>
        <extracomment>Second (optional) part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;, notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform> und %Ln Web-Quelle</numerusform>
            <numerusform> und %Ln Web-Quellen</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+13"/>
        <source>Seeding to %1 of %Ln connected peer(s)</source>
        <translation>
            <numerusform>Verteile an %1 von %Ln verbundenem Peer</numerusform>
            <numerusform>Verteile an %1 von %Ln verbundenen Peers</numerusform>
        </translation>
    </message>
    <message>
        <location line="-95"/>
        <source>Verifying local data (%1% tested)</source>
        <translation>Überprüfe lokale Daten (%1% überprüft)</translation>
    </message>
</context>
<context>
    <name>TrackerDelegate</name>
    <message numerus="yes">
        <location filename="../TrackerDelegate.cc" line="+220"/>
        <source>Got a list of%1 %Ln peer(s)%2 %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>
            <numerusform>Eine Liste erhalten mit%1 %Ln Peer%2 vor %3</numerusform>
            <numerusform>Eine Liste erhalten mit%1 %Ln Peers%2 vor %3</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer list request %1timed out%2 %3 ago; will retry</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>Anfrage nach Peerliste ist %1ausgelaufen%2 vor %3; werde erneut versuchen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Got an error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>Ein Fehler ist aufgetreten %1&quot;%2&quot;%3 vor %4</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>No updates scheduled</source>
        <translation>Keine Aktualisierungen geplant</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Asking for more peers in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Frage nach mehr Peers in %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for more peers</source>
        <translation>Anfrage für mehr Peers eingereiht</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Asking for peer counts now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Frage nach Anzahl der Peers… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="-37"/>
        <source>Tracker had%1 %Ln seeder(s)%2</source>
        <extracomment>First part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup</extracomment>
        <translation>
            <numerusform>Tracker hatte%1 %Ln Seeder%2</numerusform>
            <numerusform>Tracker hatte%1 %Ln Seeder%2</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source> and%1 %Ln leecher(s)%2 %3 ago</source>
        <extracomment>Second part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup, %3 is duration; notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform> und%1 %Ln Leecher%2 vor %3</numerusform>
            <numerusform> und%1 %Ln Leecher%2 vor %3</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tracker had %1no information%2 on peer counts %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>Tracker hatte %1keine Informationen%2 über die Anzahl an Peers vor %3</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>Got a scrape error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>&quot;Scrape&quot;-Fehler %1»%2«%3 erhalten vor %4</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>Asking for more peers now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Frage nach mehr Peers… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Asking for peer counts in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Frage nach Anzahl der Peers in %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for peer counts</source>
        <translation>Anfragen nach der Anzahl der Peers eingereiht</translation>
    </message>
</context>
<context>
    <name>TrackersDialog</name>
    <message>
        <location filename="../TrackersDialog.ui" line="+17"/>
        <source>Edit Trackers</source>
        <translation>Tracker bearbeiten</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tracker Announce URLs</source>
        <translation>Tracker Announce URLs</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>To add a backup URL, add it on the next line after a primary URL.</source>
        <translation>Um eine Backup-URL hinzuzufügen, fügen Sie sie in der nächsten Zeile nach einer primären URL ein.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>To add a new primary URL, add it after a blank line.</source>
        <translation>Eine neue Primär-URL kann nach einer Leer-Zeile eingefügt werden.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Also see Default Public Trackers in Edit &gt; Preferences &gt; Network</source>
        <translation>Siehe auch Standardmäßige öffentliche Tracker in Bearbeiten &gt; Einstellungen &gt; Netzwerk</translation>
    </message>
</context>
</TS>
